menu
explicit package
documentation
explicit.dart
ParallelOpt4<A extends Object, B extends Object, C extends Object, D extends Object>
c property
c property
dark_mode
light_mode
c
property
AsyncOpt
<
C
>
c
final
The third recipe.
Implementation
final AsyncOpt<C> c;
explicit package
documentation
explicit
ParallelOpt4<A extends Object, B extends Object, C extends Object, D extends Object>
c property
ParallelOpt4 class